=========
Powerhose
=========

Powerhose turns your CPU-bound tasks into I/O-bound tasks so your Python applications
are easier to scale.

.. image:: https://secure.travis-ci.org/mozilla-services/powerhose.png?branch=master
   :alt: Build Status
   :target: https://secure.travis-ci.org/mozilla-services/powerhose


Powerhose is an implementation of the
`Request-Reply Broker <http://zguide.zeromq.org/page:all#A-Request-Reply-Broker>`_
pattern in ZMQ.

See http://powerhose.readthedocs.org for a full documentation.
